require(nlme)
require(lme4)
require(multcomp)
require(ggplot2)
require(lattice)
se<-function(x) sqrt(var(x)/length(x))

## Set directory
setwd("/Users/davidboerma/Google Drive/Gust Response/Analysis/Stats")

######################
## Body Orientation ##
######################
# Load Data
roll  <- read.csv("Wing_PeakRoll.csv", header=TRUE)
pitch <- read.csv("Bod_PeakPitch.csv", header=TRUE)

# Test for significant difference between perturbed and uperturbed orientation
attach(roll)
y.roll <- Peak_Roll[Flight_Condition=="C"]
x.roll <- Peak_Roll[Flight_Condition=="GW"]
t.roll <- t.test(x.roll, y.roll, alt="greater")
print(rollgw_mean <- mean(Peak_Roll[Flight_Condition=="GW"]))
print(rollgw_sd   <- sd(Peak_Roll[Flight_Condition=="GW"]))
print(rollgw_se   <- se(Peak_Roll[Flight_Condition=="GW"]))
t.roll
detach(roll)

attach(pitch)
y.pitch <- Peak_Pitch[Flight_Condition=="C"]
x.pitch <- Peak_Pitch[Flight_Condition=="GB"]
t.pitch <- t.test(x.pitch, y.pitch, alt="greater")
print( pitchgb_mean <- mean(Peak_Pitch[Flight_Condition=="GB"]) )
print( pitchgb_sd   <- sd(Peak_Pitch[Flight_Condition=="GB"]) )
print( pitchgb_se   <- se(Peak_Pitch[Flight_Condition=="GB"]) )
t.pitch
detach(pitch)

#######################################################
## Humeral Elevation - amplitude and stroke duration ##
#######################################################

hum.UP = read.csv("/Users/davidboerma/Google Drive/Gust Response/Analysis/Stats/hum_amp_dur_UP.csv", header = TRUE)
attach(hum.UP)

factor(Stroke)
factor(Flight.Condition)
factor(Side)

boxplot(hum.Amplitude~Flight.Condition:Stroke)
title(main = "Humeral Elevation Amplitude per Stroke")

boxplot(hum.dur~Flight.Condition:Stroke)
title(main = "Humeral elevation duration per Stroke")

lmer.ampUP <- list()
lmer.durUP <- list()

for (i in 1:4){
  f.UP   <- Flight.Condition[Stroke==i]
  a.UP   <- hum.Amplitude[Stroke==i]
  d.UP   <- hum.dur[Stroke==i]
  ind.UP <- Individual[Stroke==i]
  
  
  lmer.ampUP[[i]] <- lmer(a.UP ~ f.UP + (1|ind.UP), na.action = na.exclude)
  lmer.durUP[[i]] <- lmer(d.UP ~ f.UP + (1|ind.UP), na.action = na.exclude)
}

i=1
summary(glht(lmer.ampUP[[i]]), linfct=mcp(f.UP = "Tukey"))
summary(glht(lmer.durUP[[i]]), linfct=mcp(f.UP = "Tukey"))
summary(lmer.ampUP[[i]])
summary(lmer.durUP[[i]])

i=2
summary(glht(lmer.ampUP[[i]]), linfct=mcp(f.UP = "Tukey"))
summary(glht(lmer.durUP[[i]]), linfct=mcp(f.UP = "Tukey"))
summary(lmer.ampUP[[i]])
summary(lmer.durUP[[i]])

i=3
summary(glht(lmer.ampUP[[i]]), linfct=mcp(f.UP = "Tukey"))
summary(glht(lmer.durUP[[i]]), linfct=mcp(f.UP = "Tukey"))
summary(lmer.ampUP[[i]])
summary(lmer.durUP[[i]])

i=4
summary(glht(lmer.ampUP[[i]]), linfct=mcp(f.UP = "Tukey"))
summary(glht(lmer.durUP[[i]]), linfct=mcp(f.UP = "Tukey"))
summary(lmer.ampUP[[i]])
summary(lmer.durUP[[i]])
