%% Analyze humeral elevation/depression duration

%% Load non-wingbeat normalized data
clear all
close all

% Variables to load for each trial
% vars = {'nk','norm_domain','Std','asym','roll','rollV','pitch','pitchV','yaw','yawV'};
vars = {'Kinematics','nk','norm_domain','asym','r','rv','p','pv','y','yv','gust'};

% Load Variables for each control trial
PYc001 = load ('/Users/davidboerma/Google Drive/Gust Response/Analysis/Control Trials/PYc001.mat',vars{:});
PYc003 = load ('/Users/davidboerma/Google Drive/Gust Response/Analysis/Control Trials/PYc003.mat',vars{:});
RBc005 = load ('/Users/davidboerma/Google Drive/Gust Response/Analysis/Control Trials/RBc005.mat',vars{:});
RBc006 = load ('/Users/davidboerma/Google Drive/Gust Response/Analysis/Control Trials/RBc006.mat',vars{:});

% Load Body-Perturbed Data
PYg006 = load('/Users/davidboerma/Google Drive/Gust Response/Analysis/Body Perturbations/PYg006.mat',vars{:});
PYg017 = load('/Users/davidboerma/Google Drive/Gust Response/Analysis/Body Perturbations/PYg017.mat',vars{:});
RBg011 = load('/Users/davidboerma/Google Drive/Gust Response/Analysis/Body Perturbations/RBg011.mat',vars{:});
GGg002 = load('/Users/davidboerma/Google Drive/Gust Response/Analysis/Body Perturbations/GGg002.mat',vars{:});
GGg021 = load('/Users/davidboerma/Google Drive/Gust Response/Analysis/Body Perturbations/GGg021.mat',vars{:});
BGg004 = load('/Users/davidboerma/Google Drive/Gust Response/Analysis/Body Perturbations/BGg004.mat',vars{:});

% Load Wing-Perturbed Data
PYg001 = load('/Users/davidboerma/Google Drive/Gust Response/Analysis/Wing Perturbations/PYg001.mat',vars{:});
PYg002 = load('/Users/davidboerma/Google Drive/Gust Response/Analysis/Wing Perturbations/PYg002.mat',vars{:});
PYg016 = load('/Users/davidboerma/Google Drive/Gust Response/Analysis/Wing Perturbations/PYg016.mat',vars{:});
GGg008 = load('/Users/davidboerma/Google Drive/Gust Response/Analysis/Wing Perturbations/GGg008.mat',vars{:});
GGg009 = load('/Users/davidboerma/Google Drive/Gust Response/Analysis/Wing Perturbations/GGg009.mat',vars{:});

% Create variables for humeral elevation data 
% Control Trials
trlc = {'PYc001','PYc003','RBc005','RBc006'};
c = NaN(400, 8);
tmp = PYc001.Kinematics(:,3:4); c(1:length(tmp),1:2) = tmp;
tmp = PYc003.Kinematics(:,3:4); c(1:length(tmp),3:4) = tmp;
tmp = RBc005.Kinematics(:,3:4); c(1:length(tmp),5:6) = tmp;
tmp = RBc006.Kinematics(:,3:4); c(1:length(tmp),7:8) = tmp;

% Wing-Perturbed Trials
trlgw = {'PYg001','PYg002','PYg016','GGg008','GGg009','BGg004'};
gw = NaN(350,10);
tmp = PYg001.Kinematics(:,3:4); gw(1:length(tmp),1:2) = tmp;
tmp = PYg002.Kinematics(:,3:4); gw(1:length(tmp),3:4) = tmp;
tmp = PYg016.Kinematics(:,3:4); gw(1:length(tmp),5:6) = tmp;
tmp = GGg008.Kinematics(:,3:4); gw(1:length(tmp),7:8) = tmp;
tmp = GGg009.Kinematics(:,3:4); gw(1:length(tmp),9:10) = tmp;

% Body-Perturbed Trials
trlgb = {'PYg006','PYg017','RBg011','GGg002','GGg021','BGg004'};
gb = NaN(350,12);
tmp =  PYg006.Kinematics(:,3:4); gb(1:length(tmp),1:2) = tmp;
tmp =  PYg017.Kinematics(:,3:4); gb(1:length(tmp),3:4) = tmp;
tmp =  RBg011.Kinematics(:,3:4); gb(1:length(tmp),5:6) = tmp;
tmp =  GGg002.Kinematics(:,3:4); gb(1:length(tmp),7:8) = tmp;
tmp =  GGg021.Kinematics(:,3:4); gb(1:length(tmp),9:10) = tmp;
tmp =  BGg004.Kinematics(:,3:4); gb(1:length(tmp),11:12) = tmp;



%% Calculate time duration of each stroke
% Do so by smoothing away bumpy data to get clean peaks and troughs at the
% correct timing. Then calculate the time between each peak/trough: each
% row represents one frame, i.e. 1/800 seconds.

dur = NaN(120,1);
figure

%%%%%%%%%%%%%%%%%%
% Control Trials %
%%%%%%%%%%%%%%%%%%
% pyc1, L then R
    for side=1:2
        clf(gcf,'reset')
        a=c(:,side); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
        pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=pks(3);
        pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
        [row, ~] = find(s==p)
        [r, ~] = find(isnan(dur)==1,1,'first'); % finds the row where the next durations should begin
        for i=1:4
            dur(r-1+i,1) = (row(i+1)-row(i))/800;
        end
        clear a s pks p r row
    end

% pyc3, L then R
    for side=3:4
        clf(gcf,'reset')
        a=c(50:end,side); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
        pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=pks(3);
        pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
        [row, ~] = find(s==p)
        [r, ~] = find(isnan(dur)==1,1,'first'); % finds the row where the next durations should begin
        for i=1:4
            dur(r-1+i,1) = (row(i+1)-row(i))/800;
        end
        clear a s pks p r row
    end

% rbc5, L then R
    for side=5:6
        clf(gcf,'reset')
        a=c(80:end,6); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
        pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=pks(3);
        pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
        [row, ~] = find(s==p)
        [r, ~] = find(isnan(dur)==1,1,'first'); % finds the row where the next durations should begin
        for i=1:4
            dur(r-1+i,1) = (row(i+1)-row(i))/800;
        end
        clear a s pks p r row
    end

% rbc6, L
    clf(gcf,'reset')
    a=c(75:end,7); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
    pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(3); p(5)=s(128,1);
    pks = -findpeaks(-s), p(2)=pks(2); p(4)=pks(3);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first'); % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row
    % rbc6, R
    clf(gcf,'reset')
    a=c(79:end,8); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
    pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=pks(3);
    pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row


%%%%%%%%%%%%%%%%%%%%%%%%%
% Wing-Perturbed Trials %
%%%%%%%%%%%%%%%%%%%%%%%%%
%     Which wing is perturbed?
%         PYg001: L
%         PYg002: L
%         PYg016: R
%         GGg008: R
%         GGg009: R
% pyg1 P(L) then U(R)
    for side=1:2
        clf(gcf,'reset')
        a=gw(50:end,side); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
        pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=pks(3);
        pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
        [row, ~] = find(s==p)
        [r, ~] = find(isnan(dur)==1,1,'first'); % finds the row where the next durations should begin
        for i=1:4
            dur(r-1+i,1) = (row(i+1)-row(i))/800;
        end
        clear a s pks p r row
    end

% pyg2 P(L) then U(R)
    for side=3:4
        clf(gcf,'reset')
        a=gw(22:end,3); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
        pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=pks(3);
        pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
        [row, ~] = find(s==p)
        [r, ~] = find(isnan(dur)==1,1,'first'); % finds the row where the next durations should begin
        for i=1:4
            dur(r-1+i,1) = (row(i+1)-row(i))/800;
        end
        clear a s pks p r row
    end

% pyg16 P(R)
    clf(gcf,'reset')
    a=gw(66:end,6); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
    pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=s(149,1);
    pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first'); % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row
% pyg16 U(L)
    clf(gcf,'reset')
    a=gw(68:end,5); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
    pks = findpeaks(s),   p(1)=pks(2); p(3)=pks(3); p(5)=s(144,1);
    pks = -findpeaks(-s), p(2)=pks(2); p(4)=pks(3);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row
    
% ggg8 P(R)
    clf(gcf,'reset')
    a=gw(85:240,8); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
    pks = findpeaks(s),   p(1)=pks(2); p(3)=pks(3); p(5)=pks(4);
    pks = -findpeaks(-s), p(2)=pks(2); p(4)=pks(3);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row
    % ggg8 U(L)
    clf(gcf,'reset')
    a=gw(85:240,7); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
    pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=pks(3);
    pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row
    
% ggg9 P(R)
    clf(gcf,'reset')
    a=gw(40:end,10); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
    pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=pks(3);
    pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row
    % ggg9 U(L)
    clf(gcf,'reset')
    a=gw(60:end,9); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
    pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=pks(3);
    pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row
    
    
%%%%%%%%%%%%%%%%%%%%%%%%%
% Body-Perturbed Trials %
%%%%%%%%%%%%%%%%%%%%%%%%%
% pyg6 L 
    clf(gcf,'reset')
    a=gb(75:end,1); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
    pks = findpeaks(s),   p(1)=pks(2); p(3)=pks(3); p(5)=pks(4);
    pks = -findpeaks(-s), p(2)=pks(2); p(4)=pks(3);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row
    % pyg6 L 
    clf(gcf,'reset')
    a=gb(75:end,2); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r')
    pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(3); p(5)=pks(4);
    pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(3);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row
    
% pyg17 L then R
for side=3:4
    clf(gcf,'reset')
    a=gb(53:end,3); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r') %, scatter(PYg017.gust,[50 50])
    pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=pks(3);
    pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row  
end

% rbg11 L then R
for side=5:6
    clf(gcf,'reset')
    a=gb(70:end,side); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r') %, scatter(RBg011.gust,[50 50])
    pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=pks(3);
    pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row  
end

% ggg2 L
    clf(gcf,'reset')
    a=gb(1:end,7); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r') , scatter(RBg011.gust,[50 50])
    pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=0;
    pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:3
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row  
    dur(100,1)=0;
    % ggg2 R
    clf(gcf,'reset')
    a=gb(1:end,8); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r') , scatter(RBg011.gust,[50 50])
    pks = findpeaks(s),   p(1)=pks(2); p(3)=pks(3); 
    pks = -findpeaks(-s), p(2)=pks(2); p(4)=pks(3);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:3
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row 
    dur(104,1)=0;
    
% ggg21 L
    clf(gcf,'reset')
    a=gb(55:end,9); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r') %, scatter(RBg011.gust,[50 50])
    pks = findpeaks(s),   p(1)=pks(2); p(3)=pks(3); p(5)=pks(4);
    pks = -findpeaks(-s), p(2)=pks(2); p(4)=pks(3);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row  
    % ggg21 R
    clf(gcf,'reset')
    a=gb(55:end,10); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r') %, scatter(RBg011.gust,[50 50])
    pks = findpeaks(s),   p(1)=pks(1); p(3)=pks(2); p(5)=pks(3);
    pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:4
        dur(r-1+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row  

% bgg4 L
    clf(gcf,'reset')
    a=gb(1:end,11); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r') , scatter(RBg011.gust,[50 50])
    pks = findpeaks(s),   p(1)=NaN; p(3)=pks(2); p(5)=pks(3);
    pks = -findpeaks(-s), p(2)=pks(2); p(4)=pks(3);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:3
        dur(r+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row 
    dur(113,1)=0;
    % bgg4 R
    clf(gcf,'reset')
    a=gb(1:end,12); s = smooth(a,15,'moving'); figure(gcf),plot(a,'k'),hold on, plot(s,'r') , scatter(RBg011.gust,[50 50])
    pks = findpeaks(s),   p(1)=NaN; p(3)=pks(1); p(5)=pks(2);
    pks = -findpeaks(-s), p(2)=pks(1); p(4)=pks(2);
    [row, ~] = find(s==p)
    [r, ~] = find(isnan(dur)==1,1,'first') % finds the row where the next durations should begin
    for i=1:3
        dur(r+i,1) = (row(i+1)-row(i))/800;
    end
    clear a s pks p r row 
    dur(117,1)=0;
    
dur(dur==0)=NaN;
    
csvwrite('hum_elev_dur.csv',dur)
