# Set directory
setwd("/Users/davidboerma/Google Drive/Gust Response/Analysis/Stats")

require(nlme)
require(lme4)
require(multcomp)
require(ggplot2)
require(lattice)

##############################################
## Compare kinematics for every 1/10-stroke ##
##############################################
kins <- read.csv('kinematics_means_newAvg.csv', header = TRUE)
attach(kins)
names(kins)
factor(Flight.Condition)
factor(Individual)
factor(Trial)
factor(Side)
factor(Stroke_whl)

lmer.ext  <-list()
lmer.elev  <-list()
lmer.prot  <-list()
lmer.elb  <-list()
lmer.hnd  <-list()
lmer.aoa  <-list()


for (i in 1:20){
  f   <- Flight.Condition[Stroke_whl==i]
  ind <- Individual[Stroke_whl==i]

  lmer.ext[[i]]  <- lmer(ext[Stroke_whl==i]  ~ f + (1|ind), na.action = na.exclude)
  lmer.elev[[i]] <- lmer(elev[Stroke_whl==i] ~ f + (1|ind), na.action = na.exclude)
  lmer.prot[[i]] <- lmer(prot[Stroke_whl==i] ~ f + (1|ind), na.action = na.exclude)
  lmer.elb[[i]]  <- lmer(elb[Stroke_whl==i]  ~ f + (1|ind), na.action = na.exclude)
  lmer.hnd[[i]]  <- lmer(hnd[Stroke_whl==i]  ~ f + (1|ind), na.action = na.exclude)
  lmer.aoa[[i]]  <- lmer(aoa[Stroke_whl==i]  ~ f + (1|ind), na.action = na.exclude)
}

##################################
## Plot Wing Extension p-values ##
##################################
# Create dataframe to store p_values for each stroke
strk    <- seq(1, 20, by=1)
i=1
x <- summary(glht(lmer.ext[[i]]), linfct=mcp(f = "Tukey"))
p.extgb  <- x$test$pvalues[2]
p.extgwP <- x$test$pvalues[3]
p.extgwU <- x$test$pvalues[4]

z.extgb  <- x$test$tstat[2]
z.extgwP <- x$test$tstat[3]
z.extgwU <- x$test$tstat[4]

rm(x)
for (i in 2:20){  
  x=summary(glht(lmer.ext[[i]]), linfct=mcp(f = "Tukey"))
  p.extgb  <- append(p.extgb,  x$test$pvalues[2],i)
  p.extgwP <- append(p.extgwP, x$test$pvalues[3],i)
  p.extgwU <- append(p.extgwU, x$test$pvalues[4],i)
  
  z.extgb  <- append(z.extgb,  x$test$tstat[2],i)
  z.extgwP <- append(z.extgwP, x$test$tstat[3],i)
  z.extgwU <- append(z.extgwU, x$test$tstat[4],i)
}

p.strks = data.frame(strk, p.extgb, p.extgwP, p.extgwU)
plot(p.strks$strk, p.strks$p.extgb)
abline(h=0.05)
title(main = "Wing Extension p-values per 1/10-stroke for Body-Pert vs Control")

plot(p.strks$strk, p.strks$p.extgwU)
abline(h=0.05)
title(main = "Wing Extension p-values per 1/10-stroke for GWU vs Control")

plot(p.strks$strk, p.strks$p.extgwP)
abline(h=0.05)
title(main = "Wing Extension p-values per 1/10-stroke for GWP vs Control")


#####################################
## Plot Humeral Elevation p-values ##
#####################################
# Create dataframe to store p_values for each stroke
strk    <- seq(1, 20, by=1)
i=1
x <- summary(glht(lmer.elev[[i]]), linfct=mcp(f = "Tukey"))
p.elevgb  <- x$test$pvalues[2]
p.elevgwP <- x$test$pvalues[3]
p.elevgwU <- x$test$pvalues[4]

z.elevgb  <- x$test$tstat[2]
z.elevgwP <- x$test$tstat[3]
z.elevgwU <- x$test$tstat[4]

rm(x)
for (i in 2:20){  
  x=summary(glht(lmer.elev[[i]]), linfct=mcp(f = "Tukey"))
  p.elevgb  <- append(p.elevgb,  x$test$pvalues[2],i)
  p.elevgwP <- append(p.elevgwP, x$test$pvalues[3],i)
  p.elevgwU <- append(p.elevgwU, x$test$pvalues[4],i)
  
  z.elevgb  <- append(z.elevgb,  x$test$tstat[2],i)
  z.elevgwP <- append(z.elevgwP, x$test$tstat[3],i)
  z.elevgwU <- append(z.elevgwU, x$test$tstat[4],i)
}

p.strks = data.frame(strk, p.elevgb, p.elevgwP, p.elevgwU)
plot(p.strks$strk, p.strks$p.elevgb)
abline(h=0.05)
title(main = "Humeral Elevation p-values per 1/10-stroke for Body-Pert vs Control")

plot(p.strks$strk, p.strks$p.elevgwU)
abline(h=0.05)
title(main = "Humeral Elevation p-values per 1/10-stroke for GWU vs Control")

plot(p.strks$strk, p.strks$p.elevgwP)
abline(h=0.05)
title(main = "Humeral Elevation p-values per 1/10-stroke for GWP vs Control")


######################################
## Plot Humeral Retraction p-values ##
######################################
# Create dataframe to store p_values for each stroke
strk    <- seq(1, 20, by=1)
i=1
x <- summary(glht(lmer.prot[[i]]), linfct=mcp(f = "Tukey"))
p.protgb  <- x$test$pvalues[2]
p.protgwP <- x$test$pvalues[3]
p.protgwU <- x$test$pvalues[4]

z.protgb  <- x$test$tstat[2]
z.protgwP <- x$test$tstat[3]
z.protgwU <- x$test$tstat[4]

rm(x)
for (i in 2:20){  
  x=summary(glht(lmer.prot[[i]]), linfct=mcp(f = "Tukey"))
  p.protgb  <- append(p.protgb,  x$test$pvalues[2],i)
  p.protgwP <- append(p.protgwP, x$test$pvalues[3],i)
  p.protgwU <- append(p.protgwU, x$test$pvalues[4],i)
  
  z.protgb  <- append(z.protgb,  x$test$tstat[2],i)
  z.protgwP <- append(z.protgwP, x$test$tstat[3],i)
  z.protgwU <- append(z.protgwU, x$test$tstat[4],i)
}

p.strks = data.frame(strk, p.protgb, p.protgwP, p.protgwU)
plot(p.strks$strk, p.strks$p.protgb)
abline(h=0.05)
title(main = "Humeral Retraction p-values per 1/10-stroke for Body-Pert vs Control")

plot(p.strks$strk, p.strks$p.protgwU)
abline(h=0.05)
title(main = "Humeral Retraction p-values per 1/10-stroke for GWU vs Control")

plot(p.strks$strk, p.strks$p.protgwP)
abline(h=0.05)
title(main = "Humeral Retraction p-values per 1/10-stroke for GWP vs Control")


###################################
## Plot Elbow Extension p-values ##
###################################
# Create dataframe to store p_values for each stroke
strk    <- seq(1, 20, by=1)
i=1
x <- summary(glht(lmer.elb[[i]]), linfct=mcp(f = "Tukey"))
p.elbgb  <- x$test$pvalues[2]
p.elbgwP <- x$test$pvalues[3]
p.elbgwU <- x$test$pvalues[4]

z.elbgb  <- x$test$tstat[2]
z.elbgwP <- x$test$tstat[3]
z.elbgwU <- x$test$tstat[4]

rm(x)
for (i in 2:20){  
  x=summary(glht(lmer.elb[[i]]), linfct=mcp(f = "Tukey"))
  p.elbgb  <- append(p.elbgb,  x$test$pvalues[2],i)
  p.elbgwP <- append(p.elbgwP, x$test$pvalues[3],i)
  p.elbgwU <- append(p.elbgwU, x$test$pvalues[4],i)
  
  z.elbgb  <- append(z.elbgb,  x$test$tstat[2],i)
  z.elbgwP <- append(z.elbgwP, x$test$tstat[3],i)
  z.elbgwU <- append(z.elbgwU, x$test$tstat[4],i)
}

p.strks = data.frame(strk, p.elbgb, p.elbgwP, p.elbgwU)
plot(p.strks$strk, p.strks$p.elbgb)
abline(h=0.05)
title(main = "Humeral Retraction p-values per 1/10-stroke for Body-Pert vs Control")

plot(p.strks$strk, p.strks$p.elbgwU)
abline(h=0.05)
title(main = "Humeral Retraction p-values per 1/10-stroke for GWU vs Control")

plot(p.strks$strk, p.strks$p.elbgwP)
abline(h=0.05)
title(main = "Humeral Retraction p-values per 1/10-stroke for GWP vs Control")


###################################
## Plot Wrist Extension p-values ##
###################################
# Create dataframe to store p_values for each stroke
strk    <- seq(1, 20, by=1)
i=1
x <- summary(glht(lmer.hnd[[i]]), linfct=mcp(f = "Tukey"))
p.hndgb  <- x$test$pvalues[2]
p.hndgwP <- x$test$pvalues[3]
p.hndgwU <- x$test$pvalues[4]

z.hndgb  <- x$test$tstat[2]
z.hndgwP <- x$test$tstat[3]
z.hndgwU <- x$test$tstat[4]

rm(x)
for (i in 2:20){  
  x=summary(glht(lmer.hnd[[i]]), linfct=mcp(f = "Tukey"))
  p.hndgb  <- append(p.hndgb,  x$test$pvalues[2],i)
  p.hndgwP <- append(p.hndgwP, x$test$pvalues[3],i)
  p.hndgwU <- append(p.hndgwU, x$test$pvalues[4],i)
  
  z.hndgb  <- append(z.hndgb,  x$test$tstat[2],i)
  z.hndgwP <- append(z.hndgwP, x$test$tstat[3],i)
  z.hndgwU <- append(z.hndgwU, x$test$tstat[4],i)
}

p.strks = data.frame(strk, p.hndgb, p.hndgwP, p.hndgwU)
plot(p.strks$strk, p.strks$p.hndgb)
abline(h=0.05)
title(main = "Humeral Retraction p-values per 1/10-stroke for Body-Pert vs Control")

plot(p.strks$strk, p.strks$p.hndgwU)
abline(h=0.05)
title(main = "Humeral Retraction p-values per 1/10-stroke for GWU vs Control")

plot(p.strks$strk, p.strks$p.hndgwP)
abline(h=0.05)
title(main = "Humeral Retraction p-values per 1/10-stroke for GWP vs Control")


########################
## Plot AoA  p-values ##
########################
# Create dataframe to store p_values for each stroke
strk     <- seq(1, 20, by=1)
i=1
x <- summary(glht(lmer.aoa[[i]]), linfct=mcp(f = "Tukey"))
p.aoagb  <- x$test$pvalues[2]
p.aoagwP <- x$test$pvalues[3]
p.aoagwU <- x$test$pvalues[4]

z.aoagb  <- x$test$tstat[2]
z.aoagwP <- x$test$tstat[3]
z.aoagwU <- x$test$tstat[4]

rm(x)
for (i in 2:20){  
  x=summary(glht(lmer.aoa[[i]]), linfct=mcp(f = "Tukey"))
  p.aoagb  <- append(p.aoagb, x$test$pvalues[2],i)
  p.aoagwP <- append(p.aoagwP, x$test$pvalues[3],i)
  p.aoagwU <- append(p.aoagwU, x$test$pvalues[4],i)
  
  z.aoagb  <- append(z.aoagb,  x$test$tstat[2],i)
  z.aoagwP <- append(z.aoagwP, x$test$tstat[3],i)
  z.aoagwU <- append(z.aoagwU, x$test$tstat[4],i)
}

p.strks = data.frame(strk, p.aoagb, p.aoagwP, p.aoagwU)
plot(p.strks$strk, p.strks$p.aoagb)
abline(h=0.05)
title(main = "AoA p-values per 1/10-stroke for Body-Pert vs Control")

plot(p.strks$strk.dec, p.strks$p.aoagwU)
abline(h=0.05)
title(main = "AoA p-values per 1/10-stroke for GWU vs Control")

plot(p.strks$strk.dec, p.strks$p.aoagwP)
abline(h=0.05)
title(main = "AoA p-values per 1/10-stroke for GWP vs Control")





# Check coefficient of variation: low values may be driving anomalously low p-vals
cv <- function(sd, avg){ 
  cv <- sd/avg*100
  return(cv)
}
cv.extc  <- list()
cv.extgb <- list()
cv.extgwU <- list()
cv.extgwP <- list()

for (i in 1:20){
  extc     <- ext[Stroke_whl==i & Flight.Condition=="C"]
  extgb    <- ext[Stroke_whl==i & Flight.Condition=="GB"]
  extgwU    <- ext[Stroke_whl==i & Flight.Condition=="GWU"]
  extgwP    <- ext[Stroke_whl==i & Flight.Condition=="GWP"]
  
  cv.extc[[i]]   <- cv(sd(extc, na.rm = TRUE), mean(extc, na.rm = TRUE))
  cv.extgb[[i]]  <- cv(sd(extgb, na.rm = TRUE), mean(extgb, na.rm = TRUE))
  cv.extgwU[[i]] <- cv(sd(extgwU, na.rm = TRUE), mean(extgwU, na.rm = TRUE))
  cv.extgwP[[i]] <- cv(sd(extgwP, na.rm = TRUE), mean(extgwP, na.rm = TRUE))
}

par(mar = c(5,5,3,5))
plot(seq(1.1,3,by=0.1), p_strks$p_extgb, type = 'p', pch = 19, ylab = "p-value",
     main = "Comparison: Wing extension in body-perturbed vs. control flights",
     xlab = "Wingbeats", col = "black")
abline(h=0.05)
par(new = TRUE)
plot(seq(1.1,3,by=0.1), cv.extgb, type = 'p', xaxt = "n", yaxt = "n",
     ylab = "", xlab = "", col="red")
axis(side = 4)
mtext("coefficient of variation", side = 4, line=3)

par(new = TRUE)
plot(seq(1.1,3,by=0.1), cv.extc, type = 'p', xaxt = "n", yaxt = "n",
     ylab = "", xlab = "", col="blue")
#axis(side = 4)
legend("topright", c("p-values", "cv.GB", "cv.C"), col=(c("black","dark red","blue")))



########################################################
## Compare left-right asymmetry for every 1/10-stroke ##
########################################################

asym <- read.csv("/Users/davidboerma/Google Drive/Gust Response/Analysis/Stats/asyms_means_newAvg.csv")

attach(asym)

factor(Flight.Condition)
factor(Individual)
factor(Trial)
factor(Stroke_whl)

lmer.asym.ext  <- list()
lmer.asym.elev <- list()
lmer.asym.prot <- list()
lmer.asym.elb  <- list()
lmer.asym.hnd  <- list()
lmer.asym.aoa  <- list()

for (i in 1:20){
  f.asym = Flight.Condition[Stroke_whl==i]
  ind.asym <- Individual[Stroke_whl==i]
  
  lmer.asym.ext[[i]]  <- lmer(ext[Stroke_whl==i]  ~ f.asym + (1|ind.asym), na.action = na.exclude)
  lmer.asym.elev[[i]] <- lmer(elev[Stroke_whl==i] ~ f.asym + (1|ind.asym), na.action = na.exclude)
  lmer.asym.prot[[i]] <- lmer(prot[Stroke_whl==i] ~ f.asym + (1|ind.asym), na.action = na.exclude)
  lmer.asym.elb[[i]]  <- lmer(elb[Stroke_whl==i]  ~ f.asym + (1|ind.asym), na.action = na.exclude)
  lmer.asym.hnd[[i]]  <- lmer(hnd[Stroke_whl==i]  ~ f.asym + (1|ind.asym), na.action = na.exclude)
  lmer.asym.aoa[[i]]  <- lmer(aoa[Stroke_whl==i]  ~ f.asym + (1|ind.asym), na.action = na.exclude)
}

##########################################
## Plot Extension Asymmetry Comparisons ##
##########################################
# Create dataframe to store p_values for each stroke
strk    <- seq(1, 20, by=1)
strk.dec <- seq(1.1,3,by=0.1) 

i=1
x <- summary(glht(lmer.asym.ext[[i]]), linfct=mcp(f.asym = "Tukey"))
p.asym.extgb  <- x$test$pvalues[2]
p.asym.extgw  <- x$test$pvalues[3]

z.asym.extgb  <- x$test$tstat[2]
z.asym.extgw  <- x$test$tstat[3]

rm(x)
for (i in 2:20){  
  x=summary(glht(lmer.asym.ext[[i]]), linfct=mcp(f.asym = "Tukey"))
  p.asym.extgb  <- append(p.asym.extgb, x$test$pvalues[2],i)
  p.asym.extgw  <- append(p.asym.extgw, x$test$pvalues[3],i)
  
  z.asym.extgb  <- append(z.asym.extgb, x$test$tstat[2],i)
  z.asym.extgw  <- append(z.asym.extgw, x$test$tstat[3],i)
}

p.asym.strks = data.frame(strk, strk.dec, p.asym.extgb, p.asym.extgw)
plot(p.asym.strks$strk.dec, p.asym.strks$p.asym.extgb)
abline(h=0.05)
title(main = "Wing Extension Asymmetry p-values per 1/10-stroke for Body-Pert vs Control")

plot(p.asym.strks$strk.dec, p.asym.strks$p.asym.extgw)
abline(h=0.05)
title(main = "Wing Extension Asymmetry p-values per 1/10-stroke for GW vs Control")


##########################################
## Plot Elevation Asymmetry Comparisons ##
##########################################
# Create dataframe to store p_values for each stroke
strk     <- seq(1, 20, by=1)
strk.dec <- seq(1.1,3,by=0.1) 
i=1
x <- summary(glht(lmer.asym.elev[[i]]), linfct=mcp(f.asym = "Tukey"))
p.asym.elevgb  <- x$test$pvalues[2]
p.asym.elevgw  <- x$test$pvalues[3]

z.asym.elevgb  <- x$test$tstat[2]
z.asym.elevgw  <- x$test$tstat[3]

rm(x)
for (i in 2:20){  
  x=summary(glht(lmer.asym.elev[[i]]), linfct=mcp(f.asym = "Tukey"))
  p.asym.elevgb  <- append(p.asym.elevgb, x$test$pvalues[2],i)
  p.asym.elevgw  <- append(p.asym.elevgw, x$test$pvalues[3],i)
  
  z.asym.elevgb  <- append(z.asym.elevgb, x$test$tstat[2],i)
  z.asym.elevgw  <- append(z.asym.elevgw, x$test$tstat[3],i)
}

p.asym.strks = data.frame(strk, strk.dec, p.asym.elevgb, p.asym.elevgw)
plot(p.asym.strks$strk.dec, p.asym.strks$p.asym.elevgb)
abline(h=0.05)
title(main = "Humeral Elevation Asymmetry p-values per 1/10-stroke for Body-Pert vs Control")

plot(p.asym.strks$strk.dec, p.asym.strks$p.asym.elevgw)
abline(h=0.05)
title(main = "Humeral Elevation Asymmetry p-values per 1/10-stroke for GW vs Control")


############################################
## Plot Protraction Asymmetry Comparisons ##
############################################
# Create dataframe to store p_values for each stroke
strk     <- seq(1, 20, by=1)
strk.dec <- seq(1.1,3,by=0.1) 
i=1
x <- summary(glht(lmer.asym.prot[[i]]), linfct=mcp(f.asym = "Tukey"))
p.asym.protgb  <- x$test$pvalues[2]
p.asym.protgw  <- x$test$pvalues[3]

z.asym.protgb  <- x$test$tstat[2]
z.asym.protgw  <- x$test$tstat[3]

rm(x)
for (i in 2:20){  
  x=summary(glht(lmer.asym.prot[[i]]), linfct=mcp(f.asym = "Tukey"))
  p.asym.protgb  <- append(p.asym.protgb, x$test$pvalues[2],i)
  p.asym.protgw  <- append(p.asym.protgw, x$test$pvalues[3],i)
  
  z.asym.protgb  <- append(z.asym.protgb, x$test$tstat[2],i)
  z.asym.protgw  <- append(z.asym.protgw, x$test$tstat[3],i)
}

p.asym.strks = data.frame(strk, strk.dec, p.asym.protgb, p.asym.protgw)
plot(p.asym.strks$strk.dec, p.asym.strks$p.asym.protgb)
abline(h=0.05)
title(main = "Humeral Protraction Asymmetry p-values per 1/10-stroke for Body-Pert vs Control")

plot(p.asym.strks$strk.dec, p.asym.strks$p.asym.protgw)
abline(h=0.05)
title(main = "Humeral Protraction Asymmetry p-values per 1/10-stroke for GW vs Control")


############################################
## Plot Elbow Angle Asymmetry Comparisons ##
############################################
# Create dataframe to store p_values for each stroke
strk     <- seq(1, 20, by=1)
strk.dec <- seq(1.1,3,by=0.1) 
i=1
x <- summary(glht(lmer.asym.elb[[i]]), linfct=mcp(f.asym = "Tukey"))
p.asym.elbgb  <- x$test$pvalues[2]
p.asym.elbgw  <- x$test$pvalues[3]

z.asym.elbgb  <- x$test$tstat[2]
z.asym.elbgw  <- x$test$tstat[3]

rm(x)
for (i in 2:20){  
  x=summary(glht(lmer.asym.elb[[i]]), linfct=mcp(f.asym = "Tukey"))
  p.asym.elbgb  <- append(p.asym.elbgb, x$test$pvalues[2],i)
  p.asym.elbgw  <- append(p.asym.elbgw, x$test$pvalues[3],i)
  
  z.asym.elbgb  <- append(z.asym.elbgb, x$test$tstat[2],i)
  z.asym.elbgw  <- append(z.asym.elbgw, x$test$tstat[3],i)
}

p.asym.strks = data.frame(strk, strk.dec, p.asym.elbgb, p.asym.elbgw)
plot(p.asym.strks$strk.dec, p.asym.strks$p.asym.elbgb)
abline(h=0.05)
title(main = "Elbow Angle Asymmetry p-values per 1/10-stroke for Body-Pert vs Control")

plot(p.asym.strks$strk.dec, p.asym.strks$p.asym.elbgw)
abline(h=0.05)
title(main = "Elbow Angle Asymmetry p-values per 1/10-stroke for GW vs Control")


############################################
## Plot Wrist Angle Asymmetry Comparisons ##
############################################
# Create dataframe to store p_values for each stroke
strk     <- seq(1, 20, by=1)
strk.dec <- seq(1.1,3,by=0.1) 
i=1
x <- summary(glht(lmer.asym.hnd[[i]]), linfct=mcp(f.asym = "Tukey"))
p.asym.hndgb  <- x$test$pvalues[2]
p.asym.hndgw  <- x$test$pvalues[3]

z.asym.hndgb  <- x$test$tstat[2]
z.asym.hndgw  <- x$test$tstat[3]

rm(x)
for (i in 2:20){  
  x=summary(glht(lmer.asym.hnd[[i]]), linfct=mcp(f.asym = "Tukey"))
  p.asym.hndgb  <- append(p.asym.hndgb, x$test$pvalues[2],i)
  p.asym.hndgw  <- append(p.asym.hndgw, x$test$pvalues[3],i)
  
  z.asym.hndgb  <- append(z.asym.hndgb, x$test$tstat[2],i)
  z.asym.hndgw  <- append(z.asym.hndgw, x$test$tstat[3],i)
}

p.asym.strks = data.frame(strk, strk.dec, p.asym.hndgb, p.asym.hndgw)
plot(p.asym.strks$strk.dec, p.asym.strks$p.asym.hndgb)
abline(h=0.05)
title(main = "Wrist Angle Asymmetry p-values per 1/10-stroke for Body-Pert vs Control")

plot(p.asym.strks$strk.dec, p.asym.strks$p.asym.hndgw)
abline(h=0.05)
title(main = "Wrist Angle Asymmetry p-values per 1/10-stroke for GW vs Control")


############################################
## Plot AoA Asymmetry Comparisons ##
############################################
# Create dataframe to store p_values for each stroke
strk     <- seq(1, 20, by=1)
strk.dec <- seq(1.1,3,by=0.1) 
i=1
x <- summary(glht(lmer.asym.aoa[[i]]), linfct=mcp(f.asym = "Tukey"))
p.asym.aoagb  <- x$test$pvalues[2]
p.asym.aoagw  <- x$test$pvalues[3]

z.asym.aoagb  <- x$test$tstat[2]
z.asym.aoagw  <- x$test$tstat[3]

rm(x)
for (i in 2:20){  
  x=summary(glht(lmer.asym.aoa[[i]]), linfct=mcp(f.asym = "Tukey"))
  p.asym.aoagb  <- append(p.asym.aoagb, x$test$pvalues[2],i)
  p.asym.aoagw  <- append(p.asym.aoagw, x$test$pvalues[3],i)
  
  z.asym.aoagb  <- append(z.asym.aoagb, x$test$tstat[2],i)
  z.asym.aoagw  <- append(z.asym.aoagw, x$test$tstat[3],i)
}

p.asym.strks = data.frame(strk, strk.dec, p.asym.aoagb, p.asym.aoagw)
plot(p.asym.strks$strk.dec, p.asym.strks$p.asym.aoagb)
abline(h=0.05)
title(main = "AoA Asymmetry p-values per 1/10-stroke for Body-Pert vs Control")

plot(p.asym.strks$strk.dec, p.asym.strks$p.asym.aoagw)
abline(h=0.05)
title(main = "AoA Asymmetry p-values per 1/10-stroke for GW vs Control")


###########################################################################
## Create Master Dataframe with all Kinematic and Asym z-vals and p-vals ##
###########################################################################
stats.kin.asym = data.frame(strk, strk.dec, z.elevgb, p.elevgb, z.asym.elevgb, p.asym.elevgb, z.elevgwP, p.elevgwP, z.elevgwU, p.elevgwU,
                            z.asym.elevgw, p.asym.elevgw,   
                            
                            z.protgb, p.protgb, z.asym.protgb, p.asym.protgb, z.protgwP, p.protgwP, z.protgwU, p.protgwU,
                            z.asym.protgw, p.asym.protgw,
                            
                            z.extgb, p.extgb, z.asym.extgb, p.asym.extgb, z.extgwP, p.extgwP, z.extgwU, p.extgwU,
                            z.asym.extgw, p.asym.extgw,
                            
                            z.elbgb, p.elbgb, z.asym.elbgb, p.asym.elbgb, z.elbgwP, p.elbgwP, z.elbgwU, p.elbgwU,
                            z.asym.elbgw, p.asym.elbgw,
                            
                            z.hndgb, p.hndgb, z.asym.hndgb, p.asym.hndgb, z.hndgwP, p.hndgwP, z.hndgwU, p.hndgwU,
                            z.asym.hndgw, p.asym.hndgw,
                            
                            z.aoagb, p.aoagb, z.asym.aoagb, p.asym.aoagb, z.aoagwP, p.aoagwP, z.aoagwU, p.aoagwU,
                            z.asym.aoagw, p.asym.aoagw
                            )
