function [ data, time ] = Load_Old_Points(trial_path)
% UPDATED 5/29/17 by David Boerma
% Updated version loads .mat files from data digitized with python tracker and
% organizes them into a matrix to be used for new kinematic analysis

% 3D Data Legend:
% Point #   Landmark   Columns
%    1        shdL       1:3
%    2        shdR       4:6
%    3        wstL       7:9
%    4        wstR      10:12
%    5        elbL      13:15
%    6        elbR      16:18
%    7         t3L      19:21
%    8         t3R      22:24
%    9         t4L      25:27
%    10        t4R      28:30
%    11        t5L      31:33
%    12        t5R      34:36
%    13       mcp3L     37:39
%    14       mcp3R     40:42
%    15       mcp4L     43:45
%    16       mcp4R     46:48
%    17       mcp5L     49:51
%    18       mcp5R     52:54
%    19       ankL      55:57
%    20       ankR      58:60
%    21       lmb       61:63
%    22       str       64:66

% trial_path = 'Y:\Gust Response\Analysis\PurpleYellow\Control003\';
% trial_path = '/Volumes/OptiBay HD/Research/Gust Response/Analysis/RedBlue/Control006/';

%Left Shoulder
if exist([trial_path 'shdL.mat'],'file') > 0
load([trial_path 'shdL.mat'],'state_val');
data(:,1:3) = (state_val(1:3,:)');
clear state_val
else data(:,1:3) = NaN;
end

%Right Shoulder
if exist([trial_path 'shdR.mat'],'file') > 0
load([trial_path 'shdR.mat'],'state_val');
data(:,4:6) = (state_val(1:3,:)');
clear state_val
else data(:,4:6) = NaN;
end

%Left Wrist
if exist([trial_path 'wstL.mat'],'file') > 0
load([trial_path 'wstL.mat'],'state_val');
data(:,7:9) = (state_val(1:3,:)');
clear state_val
else data(:,7:9) = NaN;
end

%Right Wrist
if exist([trial_path 'wstR.mat'],'file') > 0
load([trial_path 'wstR.mat'],'state_val');
data(:,10:12) = (state_val(1:3,:)');
clear state_val
else data(:,10:12) = NaN;
end

%Left Elbow
if exist([trial_path 'elbL.mat'],'file') > 0
load([trial_path 'elbL.mat'],'state_val');
data(:,13:15) = (state_val(1:3,:)');
clear state_val
else data(:,13:15) = NaN;
end

%Right Elbow
if exist([trial_path 'elbR.mat'],'file') > 0
load([trial_path 'elbR.mat'],'state_val');
data(:,16:18) = (state_val(1:3,:)');
clear state_val
else data(:,16:18) = NaN;
end

%Left t3
if exist([trial_path 't3L.mat'],'file') > 0;
load([trial_path 't3L.mat'],'state_val');
data(:,19:21) = (state_val(1:3,:)');
clear state_val
else data(:,19:21) = NaN;
end

%Right t3
if exist([trial_path 't3R.mat'],'file') > 0;
load([trial_path 't3R.mat'],'state_val');
data(:,22:24) = (state_val(1:3,:)');
clear state_val
else data(:,22:24) = NaN;
end

%Left t4
if exist([trial_path 't4L.mat'],'file') > 0;
load([trial_path 't4L.mat'],'state_val');
data(:,25:27) = (state_val(1:3,:)');
clear state_val
else data(:,25:27) = NaN;
end

%Right t4
if exist([trial_path 't4R.mat'],'file') > 0;
load([trial_path 't4R.mat'],'state_val');
data(:,28:30) = (state_val(1:3,:)');
clear state_val
else data(:,28:30) = NaN;
end

%Left t5
if exist([trial_path 't5L.mat'],'file') > 0;
load([trial_path 't5L.mat'],'state_val');
data(:,31:33) = (state_val(1:3,:)');
clear state_val
else data(:,31:33) = NaN;
end

%Right t5
if exist([trial_path 't5R.mat'],'file') > 0;
load([trial_path 't5R.mat'],'state_val');
data(:,34:36) = (state_val(1:3,:)');
clear state_val
else data(:,34:36) = NaN;
end

%Left mcp3
if exist([trial_path 'mcp3L.mat'],'file') > 0;
load([trial_path 'mcp3L.mat'],'state_val');
data(:,37:39) = (state_val(1:3,:)');
clear state_val
else data(:,37:39) = NaN;
end

%Right mcp3
if exist([trial_path 'mcp3R.mat'],'file') > 0;
load([trial_path 'mcp3R.mat'],'state_val');
data(:,40:42) = (state_val(1:3,:)');
clear state_val
else data(:,40:42) = NaN;
end

%Left mcp4
if exist([trial_path 'mcp4L.mat'],'file') > 0;
load([trial_path 'mcp4L.mat'],'state_val');
data(:,43:45) = (state_val(1:3,:)');
clear state_val
else data(:,43:45) = NaN;
end

%Right mcp4
if exist([trial_path 'mcp4R.mat'],'file') > 0;
load([trial_path 'mcp4R.mat'],'state_val');
data(:,46:48) = (state_val(1:3,:)');
clear state_val
else data(:,46:48) = NaN;
end

%Left mcp5
if exist([trial_path 'mcp5L.mat'],'file') > 0;
load([trial_path 'mcp5L.mat'],'state_val');
data(:,49:51) = (state_val(1:3,:)');
clear state_val
else data(:,49:51) = NaN;
end

%Right mcp5
if exist([trial_path 'mcp5R.mat'],'file') > 0;
load([trial_path 'mcp5R.mat'],'state_val');
data(:,52:54) = (state_val(1:3,:)');
clear state_val
else data(:,52:54) = NaN;
end

%Left Ankle
if exist([trial_path 'ankL.mat'],'file') > 0;
load([trial_path 'ankL.mat'],'state_val');
data(:,55:57) = (state_val(1:3,:)');
clear state_val
else data(:,55:57) = NaN;
end

%Right Ankle
if exist([trial_path 'ankR.mat'],'file') > 0;
load([trial_path 'ankR.mat'],'state_val');
data(:,58:60) = (state_val(1:3,:)');
clear state_val
else data(:,58:60) = NaN;
end

%Lumbar
if exist([trial_path 'lmb.mat'],'file') > 0
load([trial_path 'lmb.mat'],'state_val');
data(:,61:63) = (state_val(1:3,:)');
clear state_val
else data(:,61:63) = NaN;
end

%Sternum
if exist([trial_path 'str.mat'],'file') > 0
load([trial_path 'str.mat'],'state_val');
data(:,64:66) = (state_val(1:3,:)');
clear state_val
else data(:,64:66) = NaN;
end

%Time
time(:,:) = load([trial_path 'shdL.mat'],'time');
time = time.time;

% %Left ip3
% if exist([trial_path 'ip3L.mat'],'file') > 0;
% load([trial_path 'ip3L.mat'],'state_val');
% data(:,:,11) = (state_val(1:3,:)');
% clear state_val
% else data(:,:,11) = NaN;
% end
% 
% %Right ip3
% if exist([trial_path 'ip3R.mat'],'file') > 0;
% load([trial_path 'ip3R.mat'],'state_val');
% data(:,:,12) = (state_val(1:3,:)');
% clear state_val
% else data(:,:,12) = NaN;
% end
% 
% %Mid-Uropatagium
% if exist([trial_path 'ankR.mat'],'file') > 0;
%     for i=1:3
%         data(:,i,25) = mean([data(:,i,23), data(:,i,24)], 2);
%     end
% end
% 
% %Approx COM Body (Midpoint between str and lmb)
% if exist([trial_path 'str.mat'],'file') > 0;
%     for i=1:3
%         data(:,i,26) = mean([data(:,i,3), data(:,i,4)], 2);
%     end
% end
% 
% %Nose Leaf
% if exist([trial_path 'nl.mat'],'file') > 0;
% load([trial_path 'nl.mat'],'state_val');
% data(:,:,27) = (state_val(1:3,:)');
% clear state_val
% else data(:,:,27) = NaN;
% end
% 
end

