%% Kinematic Analysis for PurpleYellow Control001

% Part  1: Load Data
% Part  2: Define body coordinate system axes
% Part  3: Transform data into body coordinate system
% Part  4: Check local coordinate system with plot
% Part  5: Principal Components Analysis
% Part  6: Define bone segments as vectors for L/R wings
% Part  7: Calculate Wing Extension (e), Flapping Angle (Phi), and Sweep Angle (Psi)\
% Part  8: Calculate Elbow Angle
% Part  9: Calculate Wrist Ab/Adduction
% Part 10: Plot all kinematic variables

% 3D Data Legend:
% Point #   Landmark   Columns
%    1        shdL       1:3
%    2        shdR       4:6
%    3        wstL       7:9
%    4        wstR      10:12
%    5        elbL      13:15
%    6        elbR      16:18
%    7         t3L      19:21
%    8         t3R      22:24
%    9         t4L      25:27
%    10        t4R      28:30
%    11        t5L      31:33
%    12        t5R      34:36
%    13       mcp3L     37:39
%    14       mcp3R     40:42
%    15       mcp4L     43:45
%    16       mcp4R     46:48
%    17       mcp5L     49:51
%    18       mcp5R     52:54
%    19       ankL      55:57
%    20       ankR      58:60
%    21       lmb       61:63
%    22       str       64:66


%% 1. Load Data for PurpleYellow Control001
clear
close all
trl = 'PurpleYellow Control001';
% 
% [d time] = Load_Old_Points('/Volumes/Bat_Durip/Gust Response/Analysis/PurpleYellow/Control001/');
% csvwrite('PY_c001_xyzpts.csv',d)
d=csvread('/Users/davidboerma/Google Drive/Gust Response/Digitizing/PurpleYellow_fromPythonTracker/PY_c001_xyzpts.csv',1,0);

% gust = []; 

% Trim frames to eliminate NaNs (Pre-trimmed for runs from Python Tracker)
% d = data(:,:);

        % Plot motion traces to check data
        figure
        f=180;
        for i=1:22
            scatter3(d(f,i*3-2),d(f,i*3-1),d(f,i*3),20,'filled')
            hold on
        end
        hold on
        plot3([d(f,1) d(f,4)],[d(f,2) d(f,5)],[d(f,3) d(f,6)],'k')
        plot3([d(f,4) d(f,61)],[d(f,5),d(f,62)],[d(f,6),d(f,63)],'k')
        plot3([d(f,61),d(f,1)],[d(f,62) d(f,2)],[d(f,63) d(f,3)],'k')
        axis equal


%% 2. Define body coordinate system axes
% Make shdmid the origin
shdmid = (d(:,1:3) + d(:,4:6)) / 2; % midpoint between shoulders in global coordinate system
shdorig = d - repmat(shdmid,1,22);

        % Plot new points to check origin
        figure
%         f=175;
        for i=1:22
            scatter3(shdorig(f,i*3-2),shdorig(f,i*3-1),shdorig(f,i*3),20,'filled')
            hold on
        end
        hold on
        plot3([shdorig(f,1) shdorig(f,4)],[shdorig(f,2) shdorig(f,5)],[shdorig(f,3) shdorig(f,6)],'k')
        plot3([shdorig(f,4) shdorig(f,61)],[shdorig(f,5),shdorig(f,62)],[shdorig(f,6),shdorig(f,63)],'k')
        plot3([shdorig(f,61),shdorig(f,1)],[shdorig(f,62) shdorig(f,2)],[shdorig(f,63) shdorig(f,3)],'k')
        axis equal
        xlabel('X axis')
        ylabel('Y axis')
        zlabel('Z axis')

% Define local axes using shdL, shdR, and lmb
for i=1:length(shdorig)
    mid(i,:)  = (shdorig(i,1:3) + shdorig(i,4:6)) / 2; % midpoint between shoulders in local coordinate system (Origin in local coordinate system)
    Y(i,:)    = shdorig(i,1:3) - shdorig(i,4:6); % vector from shdR to shdL (shdL-shdR)
    newX(i,:) = mid(i,:) - shdorig(i,61:63); % cranio-caudal axis (from lumbar to midpoint b/t shoulders; shd.mid- - lmb)
    newZ(i,:) = cross(newX(i,:),Y(i,:));% dorso-ventral axis orthogonal to CCaxis and shoulder vector, pointing dorsally
    newY(i,:) = cross(newZ(i,:),newX(i,:));
end

for i=1:length(newX)
    Xl(i,:) = newX(i,:)/norm(newX(i,:));
    Yl(i,:) = newY(i,:)/norm(newY(i,:));
    Zl(i,:) = newZ(i,:)/norm(newZ(i,:));
end


        % Show global and local axes for current frame
        figure(2), hold on
        s=10; %scalar for making unit-length axes longer for plotting

            %Global axes
        plot3([0 s*1],[0 0],[0 0],'r','linewidth',4), hold on
        plot3([0 0],[0 s*1],[0 0],'g','linewidth',4)
        plot3([0 0],[0 0],[0 s*1],'b','linewidth',4)

            %Local axes
        plot3([0 s*Xl(f,1)],[0 s*Xl(f,2)],[0 s*Xl(f,3)],'r','linewidth',1)
        plot3([0 s*Yl(f,1)],[0 s*Yl(f,2)],[0 s*Yl(f,3)],'g','linewidth',1)
        plot3([0 s*Zl(f,1)],[0 s*Zl(f,2)],[0 s*Zl(f,3)],'b','linewidth',1)
        grid on, axis equal


%% 3. Use dot products to express points in local coordinate system (for mathematical explanation, see Parent, Rick. Computer Animation: Algorithms and Techniques. p422, Figure B.7
for i=1:length(shdorig)
   for k=1:22
       Dl(i,k*3-2:k*3) = [dot(shdorig(i,k*3-2:k*3),Xl(i,:)), dot(shdorig(i,k*3-2:k*3),Yl(i,:)), dot(shdorig(i,k*3-2:k*3),Zl(i,:))];
   end
end


%% 4. Check points in local coordinate system by plotting
        figure, hold on
        % f=14;
        for i=1:22
            scatter3(Dl(f,i*3-2),Dl(f,i*3-1),Dl(f,i*3),20,'filled')
            hold on
        end
        hold on
        plot3([Dl(f,1) Dl(f,4)],[Dl(f,2) Dl(f,5)],[Dl(f,3) Dl(f,6)],'k')
        plot3([Dl(f,4) Dl(f,61)],[Dl(f,5),Dl(f,62)],[Dl(f,6),Dl(f,63)],'k')
        plot3([Dl(f,61),Dl(f,1)],[Dl(f,62) Dl(f,2)],[Dl(f,63) Dl(f,3)],'k')
        axis equal
        xlabel('X axis')
        ylabel('Y axis')
        zlabel('Z axis')

        % calculate new local axes in local coordinate system (should align with new "global" axes)
        for i=1:length(Dl)
            m(i,:)  = (Dl(i,1:3) + Dl(i,4:6)) / 2; % midpoint between shoulders in local coordinate system (Origin in local coordinate system)
            y(i,:)    = Dl(i,1:3) - Dl(i,4:6); % vector from shdR to shdL (shdL-shdR)
            newx(i,:) = m(i,:) - Dl(i,61:63); % cranio-caudal axis (from lumbar to midpoint b/t shoulders; shd.mid- - lmb)
            newz(i,:) = cross(newx(i,:),y(i,:));% dorso-ventral axis orthogonal to CCaxis and shoulder vector, pointing dorsally
            newy(i,:) = cross(newz(i,:),newx(i,:));
        end

        for i=1:length(newx)
            xl(i,:) = newx(i,:)/norm(newx(i,:));
            yl(i,:) = newy(i,:)/norm(newy(i,:));
            zl(i,:) = newz(i,:)/norm(newz(i,:));
        end

        %Plot the axes
            %Global axes
        plot3([0 s*1],[0 0],[0 0],'r','linewidth',4), hold on
        plot3([0 0],[0 s*1],[0 0],'g','linewidth',4)
        plot3([0 0],[0 0],[0 s*1],'b','linewidth',4)

            %Local axes
            s=13;
        plot3([0 s*xl(f,1)],[0 s*xl(f,2)],[0 s*xl(f,3)],'r','linewidth',1)
        plot3([0 s*yl(f,1)],[0 s*yl(f,2)],[0 s*yl(f,3)],'g','linewidth',1)
        plot3([0 s*zl(f,1)],[0 s*zl(f,2)],[0 s*zl(f,3)],'b','linewidth',1)
        grid on, axis equal


%% 5. Principle Components Analysis Section
% 1. Use data in local coordinate system
% 2. Normalize each point to its unit variance (divide by standard deviation)
% 3. Run PCA?
% 
% % Normalize data to unit variance
% for i=1:22
%     Dl_std(:,i*3-2:i*3) = std(Dl(:,i*3-2:i*3)); %Calculate std dev for each point's x, y, and z data
% end
% 
% for i=1:size(Dl,2)
%     Dl_varnorm(:,i) = Dl(:,i)/Dl_std(:,i);
% end
% 
%         % Plot non-normalized traces for all points
%         figure
%         for i=1:22
%             plot3(Dl(:,i*3-2),Dl(:,i*3-1),Dl(:,i*3))
%            hold on
%         end
% 
%         % Plot normalized traces for all points
%         figure
%         for i=1:22
%             plot3(Dl_varnorm(:,i*3-2),Dl_varnorm(:,i*3-1),Dl_varnorm(:,i*3))
%             hold on
%         end
% 
% 
% [coeff_svd,score,latent,tsquared,explained,mu]=pca(Dl_varnorm);





%% 6. Define bones as vectors
% 3D Data Legend:
% Point #   Landmark   Columns
%    1        shdL       1:3
%    2        shdR       4:6
%    3        wstL       7:9
%    4        wstR      10:12
%    5        elbL      13:15
%    6        elbR      16:18
%    7         t3L      19:21
%    8         t3R      22:24
%    9         t4L      25:27
%    10        t4R      28:30
%    11        t5L      31:33
%    12        t5R      34:36
%    13       mcp3L     37:39
%    14       mcp3R     40:42
%    15       mcp4L     43:45
%    16       mcp4R     46:48
%    17       mcp5L     49:51
%    18       mcp5R     52:54
%    19       ankL      55:57
%    20       ankR      58:60
%    21       lmb       61:63
%    22       str       64:66

% LEFT WING
humL = Dl(:,13:15) - Dl(:,1:3);   % L Humerus (elb-shd)
radL = Dl(:,7:9)   - Dl(:,13:15); % L Radius (wst-elb)
mc3L  = Dl(:,37:39) - Dl(:,7:9); % L Metacarpal 3 (mcp3-wst)
wngL = Dl(:,19:21) - Dl(:,1:3);   % L Wing (t3-shd)
mc5L = Dl(:,49:51) - Dl(:,7:9); % L metacarpal 5 (mcp5L - wstL)
p5L  = Dl(:,31:33) - Dl(:,49:51); % L phalanges 5 (t5L - mcp5L)
d5L  = Dl(:,31:33) - Dl(:,7:9); % Left digit 5 (t5L - wstL)

% RIGHT WING
humR = Dl(:,16:18) - Dl(:,4:6);   % R Humerus (elb-shd)
radR = Dl(:,10:12) - Dl(:,16:18); % R Radius (wst-elb)
mcR  = Dl(:,40:42) - Dl(:,10:12); % R Metacarpal 3 (mcp3-wst)
wngR = Dl(:,22:24) - Dl(:,4:6);   % R Wing (t3-shd)
mc5R = Dl(:,52:54) - Dl(:,10:12); % R metacarpal 5 (mcp5R - wstR)
p5R  = Dl(:,34:36) - Dl(:,52:54); % R phalanges 5 (t5R - mcp5R)
d5R  = Dl(:,34:36) - Dl(:,10:12); % R digit 5 (t5R - wstR)

%         figure
%         for f=200
%         scatter3(humL(f,1),humL(f,2),humL(f,3),'filled','b'), hold on
%         scatter3(humR(f,1),humR(f,2),humR(f,3),'filled','r'), axis equal, grid on
%         legend('Left','Right')
%         plot3([0 humL(f,1)],[0 humL(f,2)],[0 humL(f,3)],'b')
%         plot3([0 humR(f,1)],[0 humR(f,2)],[0 humR(f,3)],'r')
%         end
%         
%         figure
%         for f=1:length(wngL)
%         scatter3(wngL(f,1),wngL(f,2),wngL(f,3),'filled','b'), hold on
%         scatter3(wngR(f,1),wngR(f,2),wngR(f,3),'filled','r'), axis equal, grid on
%         legend('Left','Right')
%         plot3([0 wngL(f,1)],[0 wngL(f,2)],[0 wngL(f,3)],'b')
%         plot3([0 wngR(f,1)],[0 wngR(f,2)],[0 wngR(f,3)],'r')
%         end



%% 7. Calculate Wing Extension (e) using wng vectors, and Flapping Angle (Phi) and Sweep Angle (Psi) using hum vectors
% All calculations with data in Local Coordinate System
% Extension = magnitude of wng vector
% Flapping Angle = In the YZ plane, angle between hum vector and -Z axis
% Sweep Angle = In XY plane, angle between wng vector and -X axis
% For each angle, 0 degrees is a hypothetical pose in which the humerus is pointing ventrally, parallell to the -Z axis

% Left Wing, use +Y axis because +Y is to the bat's left in the LCS
    % wngL_xy = wngL(:,1:2);
    % wngL_yz = wngL(:,2:3);
humL_xy = humL(:,1:2);
humL_yz = humL(:,2:3);

for i=1:length(wngL)
    wngL_e(i,:)   = norm(wngL(i,:));  %Extension
    humL_phi(i,:) = acosd(dot(humL_yz(i,:),[0,-1]) / (norm(humL_yz(i,:)) * norm([0,-1])));    %Phi: Flapping Angle, [1,0] is a vector along the y-axis in the YZ plane
    humL_psi(i,:) = acosd(dot(humL_xy(i,:),[-1,0]) / (norm(humL_xy(i,:)) * norm([-1,0])));
%     wngL_phi(i,:) = acosd(dot(wngL_yz(i,:),[0,-1]) / (norm(wngL_yz(i,:)) * norm([0,-1])));    %Phi: Flapping Angle, [1,0] is a vector along the y-axis in the YZ plane
%     wngL_psi(i,:) = acosd(dot(wngL_xy(i,:),[0,1]) / (norm(wngL_xy(i,:)) * norm([0,1])));
end


% Right Wing, use -Y axis because -Y is to the bat's right in the LCS
    % wngR_xy = wngR(:,1:2);
    % wngR_yz = wngR(:,2:3);
humR_xy = humR(:,1:2);
humR_yz = humR(:,2:3);

for i=1:length(wngR)
    wngR_e(i,:)   = norm(wngR(i,:));
    humR_phi(i,:) = acosd(dot(humR_yz(i,:),[0,-1]) / (norm(humR_yz(i,:)) * norm([0,-1])));
    humR_psi(i,:) = acosd(dot(humR_xy(i,:),[-1,0]) / (norm(humR_xy(i,:)) * norm([-1,0])));
%     wngR_phi(i,:) = acosd(dot(wngR_yz(i,:),[0,-1]) / (norm(wngR_yz(i,:)) * norm([0,-1])));
%     wngR_psi(i,:) = acosd(dot(wngR_xy(i,:),[0,-1]) / (norm(wngR_xy(i,:)) * norm([0,-1])));
end

% Redo calculation using spherical coordinates (See Riskin et al. 2008. Quantifying the complexity of bat wing kinematics. J. Theoretical Biology.
% [protraction/retraction, elevation/depression, humerus length] = [hum_sph(:,1), hum_sph(:,3), hum_sph(:,3)]

[humL_sph(:,1), humL_sph(:,2), humL_sph(:,3)] = cart2sph(humL(:,1), humL(:,2), humL(:,3));
humL_sph(:,1) = rad2deg(humL_sph(:,1));
humL_sph(:,2) = rad2deg(humL_sph(:,2));

[humR_sph(:,1), humR_sph(:,2), humR_sph(:,3)] = cart2sph(humR(:,1), humR(:,2), humR(:,3));
humR_sph(:,1) = rad2deg(humR_sph(:,1));
humR_sph(:,2) = rad2deg(humR_sph(:,2));

% Check spherical coordinate calculations against other method
figure, hold on, 
plot(humL_sph(:,1),'r'), plot(-humL_psi,'--r')
plot(humL_sph(:,2),'b'), plot(humL_phi,'--b')
plot(humL_sph(:,3),'k')
legend('Sweep-sph_L','Sweep-d_L','Elevation-sph_L','Elevation-d_L','humerus_L length')

figure, hold on, 
plot(humR_sph(:,1),'r'), plot(-humR_psi,'--r')
plot(humR_sph(:,2),'b'), plot(humR_phi,'--b')
plot(humR_sph(:,3),'k')
legend('Sweep-sph_R','Sweep-d_R','Elevation-sph_R','Elevation-d_R','humerus_R length')

%% 8. Calculate Elbow Angle
% Angle between the rad and hum vectors at the origin... thus 180 - that angle

for i=1:length(humL)
    elbL(i,:) = 180 - acosd(dot(humL(i,:),radL(i,:)) / (norm(humL(i,:)) * norm(radL(i,:))));
    elbR(i,:) = 180 - acosd(dot(humR(i,:),radR(i,:)) / (norm(humR(i,:)) * norm(radR(i,:))));
end

%% 9. Wrist Angle (Ad/Abduction)
% Angle between metacarpal 5 and the radius
% Joint coordinate system is constructed as follows:
%   Origin is at elbow
%   X-Axis: elb -> wst (rad vector)
%   Z-Axis: rad X hum (cross product of radius and humerus; vector orthogonal to radius and humerus
%   Y-Axis: Z X rad (cross product of Z axis and radius

% ***** LEFT WING *********************************************************
% Define Joint Coordinate System
xL = radL;
for i=1:length(radL)
    zL(i,:) = cross(radL(i,:),humL(i,:));
end
for i=1:length(radL)
    yL(i,:) = cross(zL(i,:),radL(i,:));
end
for i=1:length(radL)
    X_Lwst(i,:) = xL(i,:)/norm(xL(i,:));
    Y_Lwst(i,:) = yL(i,:)/norm(yL(i,:));
    Z_Lwst(i,:) = zL(i,:)/norm(zL(i,:));
end

% Express digit 5, humerus, and radius vecors in the JCS
for i=1:length(mc5L)
    mc5L_jcs(i,:) = [dot(mc5L(i,:),X_Lwst(i,:)), dot(mc5L(i,:),Y_Lwst(i,:)), dot(mc5L(i,:),Z_Lwst(i,:))];
    p5L_jcs(i,:)  = [dot(p5L(i,:),X_Lwst(i,:)), dot(p5L(i,:),Y_Lwst(i,:)), dot(p5L(i,:),Z_Lwst(i,:))];
    d5L_jcs(i,:)  = [dot(d5L(i,:),X_Lwst(i,:)), dot(d5L(i,:),Y_Lwst(i,:)), dot(d5L(i,:),Z_Lwst(i,:))]; 
    radL_jcs(i,:) = [dot(radL(i,:),X_Lwst(i,:)), dot(radL(i,:),Y_Lwst(i,:)), dot(radL(i,:),Z_Lwst(i,:))]; 
    humL_jcs(i,:) = [dot(humL(i,:),X_Lwst(i,:)), dot(humL(i,:),Y_Lwst(i,:)), dot(humL(i,:),Z_Lwst(i,:))];
end

% Calculate Wrist Ad/Abduction 
% This is the angle between mc5 and rad in the JCS's X-Y plane
for i=1:length(mc5L_jcs)
    wstL_ab(i,:) = 180 - acosd(dot(mc5L_jcs(i,1:2),radL_jcs(i,1:2)) / (norm(mc5L_jcs(i,1:2))*norm(radL_jcs(i,1:2)))); %subtract from 180 degrees because the mc5L and radL vectors are translated, tip-to-tip the origin instead of tip to tail
end



%         
%         % Check JCS
%         % calculate new jcs axes in jcs coordinate system (should align with new "global" axes)
%         xtest = radL_jcs;
%         for i=1:length(radL_jcs)
%             ztest(i,:) = cross(radL_jcs(i,:),humL_jcs(i,:));
%         end
%         for i=1:length(radL_jcs)
%             ytest(i,:) = cross(ztest(i,:),radL_jcs(i,:));
%         end
%         for i=1:length(radL_jcs)
%             X_test(i,:) = xtest(i,:)/norm(xtest(i,:));
%             Y_test(i,:) = ytest(i,:)/norm(ytest(i,:));
%             Z_test(i,:) = ztest(i,:)/norm(ztest(i,:));
%         end
% 
%         % Show local and coordinate axes for current frame
%         figure, hold on % plot from section 4
%         s=10; %scalar for making unit-length axes longer for plotting
%         for f=150:200
%         %JCS axes
%         plot3([0 s*X_test(f,1)],[0 s*X_test(f,2)],[0 s*X_test(f,3)],'r','linewidth',1)
%         plot3([0 s*Y_test(f,1)],[0 s*Y_test(f,2)],[0 s*Y_test(f,3)],'g','linewidth',1)
%         plot3([0 s*Z_test(f,1)],[0 s*Z_test(f,2)],[0 s*Z_test(f,3)],'b','linewidth',1)
%         grid on, axis equal
%         
%         %Digit 5 Vectors
%         scatter3(mc5L_jcs(f,1),mc5L_jcs(f,2),mc5L_jcs(f,3),'r')
%         plot3([0 mc5L_jcs(f,1)], [0 mc5L_jcs(f,2)], [0 mc5L_jcs(f,3)],'r')
%         
%         scatter3(radL_jcs(f,1),radL_jcs(f,2),radL_jcs(f,3),'k')
%         plot3([0 radL_jcs(f,1)], [0 radL_jcs(f,2)], [0 radL_jcs(f,3)],'k')
%         
%         scatter3(humL_jcs(f,1),humL_jcs(f,2),humL_jcs(f,3),'m')
%         plot3([0 humL_jcs(f,1)], [0 humL_jcs(f,2)], [0 humL_jcs(f,3)],'m')
%         end
%         xlabel('X-Axis')
%         ylabel('Y-Axis')
%         zlabel('Z-Axis')

  
% ***** RIGHT WING *********************************************************
% Define Joint Coordinate System
xR = radR;
for i=1:length(radR)
    zR(i,:) = cross(radR(i,:),humR(i,:));
end
for i=1:length(radR)
    yR(i,:) = cross(zR(i,:),radR(i,:));
end
for i=1:length(radL)
    X_Rwst(i,:) = xR(i,:)/norm(xR(i,:));
    Y_Rwst(i,:) = yR(i,:)/norm(yR(i,:));
    Z_Rwst(i,:) = zR(i,:)/norm(zR(i,:));
end

% Express digit 5, humerus, and radius vecors in the JCS
for i=1:length(mc5R)
    mc5R_jcs(i,:) = [dot(mc5R(i,:),X_Rwst(i,:)), dot(mc5R(i,:),Y_Rwst(i,:)), dot(mc5R(i,:),Z_Rwst(i,:))];
    p5R_jcs(i,:)  = [dot(p5R(i,:),X_Rwst(i,:)), dot(p5R(i,:),Y_Rwst(i,:)), dot(p5R(i,:),Z_Rwst(i,:))];
    d5R_jcs(i,:)  = [dot(d5R(i,:),X_Rwst(i,:)), dot(d5R(i,:),Y_Rwst(i,:)), dot(d5R(i,:),Z_Rwst(i,:))]; 
    radR_jcs(i,:) = [dot(radR(i,:),X_Rwst(i,:)), dot(radR(i,:),Y_Rwst(i,:)), dot(radR(i,:),Z_Rwst(i,:))]; 
    humR_jcs(i,:) = [dot(humR(i,:),X_Rwst(i,:)), dot(humR(i,:),Y_Rwst(i,:)), dot(humR(i,:),Z_Rwst(i,:))];
end

% *************** 5/26 - SKETCH THIS OUT FIRST TO MAKE SURE YOUR GEOMETRY IS CORRECT!!! ***************
% Calculate Wrist Ad/Abduction 
% This is the angle between mc5 and rad in the JCS's X-Y plane
for i=1:length(mc5R_jcs)
    wstR_ab(i,:) = 180 - acosd(dot(mc5R_jcs(i,1:2),radR_jcs(i,1:2)) / (norm(mc5R_jcs(i,1:2))*norm(radR_jcs(i,1:2)))); %subtract from 180 degrees because the mc5L and radL vectors are translated, tip-to-tip the origin instead of tip to tail
end

%         % Check JCS
%         % calculate new jcs axes in jcs coordinate system (should align with new "global" axes)
%         xtest = radR_jcs;
%         for i=1:length(radR_jcs)
%             ztest(i,:) = cross(radR_jcs(i,:),humR_jcs(i,:));
%         end
%         for i=1:length(radR_jcs)
%             ytest(i,:) = cross(ztest(i,:),radR_jcs(i,:));
%         end
%         for i=1:length(radR_jcs)
%             X_test(i,:) = xtest(i,:)/norm(xtest(i,:));
%             Y_test(i,:) = ytest(i,:)/norm(ytest(i,:));
%             Z_test(i,:) = ztest(i,:)/norm(ztest(i,:));
%         end
% 
%         % Show local and coordinate axes for current frame
%         figure, hold on % plot from section 4
%         s=10; %scalar for making unit-length axes longer for plotting
%         for f=150:200
%         %JCS axes
%         plot3([0 s*X_test(f,1)],[0 s*X_test(f,2)],[0 s*X_test(f,3)],'r','linewidth',1)
%         plot3([0 s*Y_test(f,1)],[0 s*Y_test(f,2)],[0 s*Y_test(f,3)],'g','linewidth',1)
%         plot3([0 s*Z_test(f,1)],[0 s*Z_test(f,2)],[0 s*Z_test(f,3)],'b','linewidth',1)
%         grid on, axis equal
%         
%         %Digit 5 Vectors
%         scatter3(mc5R_jcs(f,1),mc5R_jcs(f,2),mc5R_jcs(f,3),'r')
%         plot3([0 mc5R_jcs(f,1)], [0 mc5R_jcs(f,2)], [0 mc5R_jcs(f,3)],'r')
%         
%         scatter3(radR_jcs(f,1),radR_jcs(f,2),radR_jcs(f,3),'k')
%         plot3([0 radR_jcs(f,1)], [0 radR_jcs(f,2)], [0 radR_jcs(f,3)],'k')
%        
%         scatter3(humR_jcs(f,1),humR_jcs(f,2),humR_jcs(f,3),'m')
%         plot3([0 humR_jcs(f,1)], [0 humR_jcs(f,2)], [0 humR_jcs(f,3)],'m')
%         end
%         xlabel('X-Axis')
%         ylabel('Y-Axis')
%         zlabel('Z-Axis')

%% Part 10: Plot All Kinematics

        figure
        % Plot wing extension for L/R sides
        numplots = 5;
        subplot(numplots,1,1)
        plot(wngL_e,'b'), hold on
        plot(wngR_e,'r'), grid on
        xlm = [0 250]; ylm = [0 15];
%         plot([gust(1) gust(1)],[ylm(1) ylm(2)],'--k','linewidth',2)
%         plot([gust(2) gust(2)],[ylm(1) ylm(2)],'--k','linewidth',2)
        xlim(xlm), ylim(ylm)
        ylabel('Extension (cm)')
        legend('Left','Right')
        title({'PurpleYellow Control001';'';'Wing Extension (e)'})
        
        % Plot flapping angle for L/R sides
        subplot(numplots,1,2)
        plot(humL_phi,'b'), hold on
        plot(humR_phi,'r'), grid on
        xlm = [0 250]; ylm = [0 200];
%         plot([gust(1) gust(1)],[ylm(1) ylm(2)],'--k','linewidth',2)
%         plot([gust(2) gust(2)],[ylm(1) ylm(2)],'--k','linewidth',2)
        xlim(xlm), ylim(ylm)
        ylabel('Angle (Degrees)')
        legend('Left','Right')
        title('Flapping Angle (\phi)')
        
        % Plot sweep angle for L/R sides
        subplot(numplots,1,3)
        plot(humL_psi,'b'), hold on
        plot(humR_psi,'r'), grid on
        xlm = [0 250]; ylm = [0 120];
%         plot([gust(1) gust(1)],[ylm(1) ylm(2)],'--k','linewidth',2)
%         plot([gust(2) gust(2)],[ylm(1) ylm(2)],'--k','linewidth',2)
        xlim(xlm), ylim(ylm)
        ylabel('Angle (Degrees)')
        legend('Left','Right')
        title('Sweep Angle (\psi)')
        
        %Plot elbow angle for L/R sides
        subplot(numplots,1,4)
        plot(elbL,'b'), hold on
        plot(elbR,'r'), grid on
        xlm = [0 250]; ylm = [0 130];
%         plot([gust(1) gust(1)],[ylm(1) ylm(2)],'--k','linewidth',2)
%         plot([gust(2) gust(2)],[ylm(1) ylm(2)],'--k','linewidth',2)
        xlim(xlm), ylim(ylm)
        ylabel('Angle (Degrees)')
        legend('Left','Right')
        title('Elbow Angle')
        xlabel('Frame')
        
        %Plot wrist adduction for L/R sides
        subplot(numplots,1,5)
        plot(wstL_ab,'b'), hold on
        plot(wstR_ab,'r'), grid on
%         xlm = [0 250]; ylm = [0 90];
%         plot([gust(1) gust(1)],[ylm(1) ylm(2)],'--k','linewidth',2)
%         plot([gust(2) gust(2)],[ylm(1) ylm(2)],'--k','linewidth',2)
        xlim(xlm), ylim(ylm)
        ylabel('Angle (Degrees)')
        legend('Left','Right')
        title('Wrist Abduction')
        xlabel('Frame')

        





% figure
% for i=1:length(humL)
%     plot3(humL(i,1),humL(i,2),humL(i,3),'b'), hold on
%     plot3([0 humL(i,1)],[0 humL(i,2)],[0 humL(i,3)],'b')
%     plot3(radL(i,1),radL(i,2),radL(i,3),'r')
%     plot3([0 radL(i,1)],[0 radL(i,2)],[0 radL(i,3)],'r')
% end
% axis equal, grid on

