%% Output is 3d.  frames,xyz,pos/vel/acc
function[smoothed_data, first_der_data, second_der_data]=...
    smooth_data(data,polynomial_fit,window_size,fs)
%data= vector
%polynomial_fit= the order of the highest polynomial used to fit the model
%window_size= total size of window on both sides of interrogation region
%fs= sampling frequency
%% sets default smoothing to 2nd degree polynomial and window size to +/-7
if nargin<4
    fs=1;
end
if nargin<3
    window_size=15;
end
if nargin<2
    polynomial_fit=2;
end

%% reports errors for incorrect inputs
if isequal(floor(window_size),ceil(window_size))==0
    error('window_size must be an odd integer')
end
if isequal(ceil(window_size*.5),floor(window_size*.5))==1;
    error('window_size must be odd');
end
if size(squeeze(data),3)~=1 || min(size(squeeze(data)))~=1
    error('data must be a vector: One row or column of data only')
end
%% smooths data based on window size.
smoothed_data  =zeros(size(data));
first_der_data =zeros(size(data));
second_der_data=zeros(size(data));

% most of the data is fitted here, except the ends
for q=ceil(window_size*.5):length(data)-floor(.5*window_size)
    fit_values=polyfit(((q-floor(window_size*.5)):(q+floor(window_size*.5)))',...
        data((q-floor(window_size*.5)):(q+floor(window_size*.5))),...
        polynomial_fit);
    smoothed_data(q)  =fs^0*polyval(fit_values,q);
    %1st derivative
    first_fit_values  =polyder(fit_values);
    first_der_data(q) =fs^1*polyval(first_fit_values,q);
    %2nd derivative
    second_fit_values =polyder(first_fit_values);
    second_der_data(q)=fs^2*polyval(second_fit_values,q);
end
% smooths first part of the data
for q=1:floor(window_size*.5)
    fit_values=polyfit((1:q+floor(window_size*.5))',...
        data(1:q+floor(window_size*.5)),...
        polynomial_fit);
    smoothed_data(q)  =fs^0*polyval(fit_values,q);
    %1st derivative
    first_fit_values  =polyder(fit_values);
    first_der_data(q) =fs^1*polyval(first_fit_values,q);
    %2nd derivative
    second_fit_values =polyder(first_fit_values);
    second_der_data(q)=fs^2*polyval(second_fit_values,q);
end
% smooths last part of data
for q=(length(data)-floor(.5*window_size)+1):length(data)
    fit_values=polyfit((q-floor(window_size*.5):length(data))',...
        data(q-floor(window_size*.5):length(data)),...
        polynomial_fit);
    smoothed_data(q)  =fs^0*polyval(fit_values,q);
    %1st derivative
    first_fit_values  =polyder(fit_values);
    first_der_data(q) =fs^1*polyval(first_fit_values,q);
    %2nd derivative
    second_fit_values =polyder(first_fit_values);
    second_der_data(q)=fs^2*polyval(second_fit_values,q);
end
end