function [ wngext_L, wngext_R, elev_L, elev_R, prot_L, prot_R, elbL, elbR, dang3_radL, dang3_radR ] = KinematicsCalculations( LCSdata )
%UNTITLED3 Summary of this function goes here
%   Detailed explanation goes here
%% Define bones as vector
% 3D Data Legend:
% Point #   Landmark   Columns
%    1        shdL       1:3
%    2        shdR       4:6
%    3        wstL       7:9
%    4        wstR      10:12
%    5        elbL      13:15
%    6        elbR      16:18
%    7         t3L      19:21
%    8         t3R      22:24
%    9         t4L      25:27
%    10        t4R      28:30
%    11        t5L      31:33
%    12        t5R      34:36
%    13       mcp3L     37:39
%    14       mcp3R     40:42
%    15       mcp4L     43:45
%    16       mcp4R     46:48
%    17       mcp5L     49:51
%    18       mcp5R     52:54
%    19       ankL      55:57
%    20       ankR      58:60
%    21       lmb       61:63
%    22       str       64:66

Dl = LCSdata;

% LEFT WING
humL = Dl(:,13:15) - Dl(:,1:3);   % L Humerus (elb-shd)
radL = Dl(:,7:9)   - Dl(:,13:15); % L Radius (wst-elb)
mc3L = Dl(:,37:39) - Dl(:,7:9);   % L Metacarpal 3 (mcp3-wst)
mc4L = Dl(:,43:45) - Dl(:,7:9);   % L Metacarpal 4 (mcp4-wst)
mc5L = Dl(:,49:51) - Dl(:,7:9);   % L Metacarpal 5 (mcp5L - wstL)
p5L  = Dl(:,31:33) - Dl(:,49:51); % L phalanges 5 (t5L - mcp5L)
d5L  = Dl(:,31:33) - Dl(:,7:9);   % Left digit 5 (t5L - wstL)
wngL = Dl(:,19:21) - Dl(:,1:3);   % L Wing (t3-shd)

% RIGHT WING
humR = Dl(:,16:18) - Dl(:,4:6);   % R Humerus (elb-shd)
radR = Dl(:,10:12) - Dl(:,16:18); % R Radius (wst-elb)
mc3R = Dl(:,40:42) - Dl(:,10:12); % R Metacarpal 3 (mcp3-wst)
mc4R = Dl(:,46:48) - Dl(:,10:12); % R Metacarpal 4 (mcp4-wst)  
mc5R = Dl(:,52:54) - Dl(:,10:12); % R Metacarpal 5 (mcp5R - wstR)
p5R  = Dl(:,34:36) - Dl(:,52:54); % R phalanges 5 (t5R - mcp5R)
d5R  = Dl(:,34:36) - Dl(:,10:12); % R digit 5 (t5R - wstR)
wngR = Dl(:,22:24) - Dl(:,4:6);   % R Wing (t3-shd)

%         figure
%         for f=200
%         scatter3(humL(f,1),humL(f,2),humL(f,3),'filled','b'), hold on
%         scatter3(humR(f,1),humR(f,2),humR(f,3),'filled','r'), axis equal, grid on
%         legend('Left','Right')
%         plot3([0 humL(f,1)],[0 humL(f,2)],[0 humL(f,3)],'b')
%         plot3([0 humR(f,1)],[0 humR(f,2)],[0 humR(f,3)],'r')
%         end
%         
%         figure
%         for f=1:length(wngL)
%         scatter3(wngL(f,1),wngL(f,2),wngL(f,3),'filled','b'), hold on
%         scatter3(wngR(f,1),wngR(f,2),wngR(f,3),'filled','r'), axis equal, grid on
%         legend('Left','Right')
%         plot3([0 wngL(f,1)],[0 wngL(f,2)],[0 wngL(f,3)],'b')
%         plot3([0 wngR(f,1)],[0 wngR(f,2)],[0 wngR(f,3)],'r')
%         end

%% 1. Calculate Wing Extension (e) using wng vectors
% All calculations with data in Local Coordinate System
% Extension = magnitude of wng vector

% Wing Extension
for i=1:length(Dl)
    wngext_L(i,:)   = norm(wngL(i,:));  %Extension
    wngext_R(i,:)   = norm(wngR(i,:));  %Extension
end

% If extension in mm, convert to cm
if wngext_L(round(length(wngext_L)/2), :) > 15 % sample middle frame to avoid terminal NaNs
    wngext_L = wngext_L/10;
    wngext_R = wngext_R/10;
end

%% 2. Calculate Humeral Elevation (Phi) and Protraction (Psi) using hum vectors
% This parameter is also considered "flapping" and "Sweep"
% Calculationsfor humeral motion performed using spherical coordinates of humerus in local coordinate system
% (See Riskin et al. 2008. Quantifying the complexity of bat wing kinematics. J. Theoretical Biology., Table 1)
% [protraction/retraction, elevation/depression, humerus length] = [hum_sph(:,1), hum_sph(:,3), hum_sph(:,3)]

% Humeral Elevation and Protraction
[humL_sph(:,1), humL_sph(:,2), humL_sph(:,3)] = cart2sph(humL(:,1), humL(:,2), humL(:,3));
humL_sph(:,1) = rad2deg(humL_sph(:,1));
humL_sph(:,2) = rad2deg(humL_sph(:,2));

[humR_sph(:,1), humR_sph(:,2), humR_sph(:,3)] = cart2sph(humR(:,1), humR(:,2), humR(:,3));
humR_sph(:,1) = rad2deg(humR_sph(:,1));
humR_sph(:,2) = rad2deg(humR_sph(:,2));

% close all,figure,plot(humL_sph(:,1)), hold on, plot(humR_sph(:,1))

% Correct humeral angles for frames where radians excede 2pi
% For Protraction/Retraction Angle
if size(find(-humR_sph(:,1)<0)) > 0
    ix = find(-humR_sph(:,1)<0);
    for i=ix
        humR_sph(i,1) = humR_sph(i,1)-360;
    end
end

% figure,plot(humL_sph(:,1)), hold on, plot(humR_sph(:,1))

if size(find(humL_sph(:,1)<0)) > 0
    ix = find(humL_sph(:,1)<0);
    for i=ix
        humL_sph(i,1) = humL_sph(i,1)+360;
    end
end

% figure,plot(humL_sph(:,1)), hold on, plot(humR_sph(:,1))

elev_L = humL_sph(:,2);
elev_R = humR_sph(:,2);

prot_L = humL_sph(:,1);
prot_R = humR_sph(:,1);


%% 3. Calculate Elbow Flexion/Extension
% Angle between the rad and hum vectors at the origin... thus 180 - that angle

for i=1:length(humL)
    elbL(i,:) = 180 - acosd(dot(humL(i,:),radL(i,:)) / (norm(humL(i,:)) * norm(radL(i,:))));
    elbR(i,:) = 180 - acosd(dot(humR(i,:),radR(i,:)) / (norm(humR(i,:)) * norm(radR(i,:))));
end

%% 4. Calculate Digit Spreading/folding (Ab/Adduction)
% Angles between digits III & IV; IV & V; and V & Radius. See Riskin et al. 2008. Quantifying the complexity of bat wing kinematics. J. Theoretical Biology., Table 1
% Angle between mcIII and the radius captures total handwing spreading/folding.

for i=1:length(Dl)
    dang3_4L(i,:)   = acosd(dot(mc3L(i,:),mc4L(i,:)) / (norm(mc3L(i,:)) * norm(mc4L(i,:))));
    dang3_4R(i,:)   = acosd(dot(mc3R(i,:),mc4R(i,:)) / (norm(mc3R(i,:)) * norm(mc4R(i,:))));
    dang4_5L(i,:)   = acosd(dot(mc4L(i,:),mc5L(i,:)) / (norm(mc4L(i,:)) * norm(mc5L(i,:))));
    dang4_5R(i,:)   = acosd(dot(mc4R(i,:),mc5R(i,:)) / (norm(mc4R(i,:)) * norm(mc5R(i,:))));
    dang5_radL(i,:) = 180 - acosd(dot(mc5L(i,:),radL(i,:)) / (norm(mc5L(i,:)) * norm(radL(i,:))));
    dang5_radR(i,:) = 180 - acosd(dot(mc5R(i,:),radR(i,:)) / (norm(mc5R(i,:)) * norm(radR(i,:))));
    dang3_radL(i,:) = 180 - acosd(dot(mc3L(i,:),radL(i,:)) / (norm(mc3L(i,:)) * norm(radL(i,:))));
    dang3_radR(i,:) = 180 - acosd(dot(mc3R(i,:),radR(i,:)) / (norm(mc3R(i,:)) * norm(radR(i,:))));
end

%         figure
%         p1 = mc3L;
%         p2 = radL;
%         for f=165
%         scatter3(p1(f,1),p1(f,2),p1(f,3),'filled','b'), hold on
%         scatter3(p2(f,1),p2(f,2),p2(f,3),'filled','r'), axis equal, grid on
%         legend('p1','p2')
%         plot3([0 p1(f,1)],[0 p1(f,2)],[0 p1(f,3)],'b')
%         plot3([0 p2(f,1)],[0 p2(f,2)],[0 p2(f,3)],'r')
%         end
%         
%         figure
%         subplot(4,1,1), plot(dang3_radL), title('III vs Rad'), xlim([0 length(Dl)]), ylim([0 180])
%         subplot(4,1,2), plot(dang5_radL), title('V vs Rad'), xlim([0 length(Dl)]), ylim([0 180])
%         subplot(4,1,3), plot(dang3_4L), title('III vs IV'), xlim([0 length(Dl)]), ylim([0 180])
%         subplot(4,1,4), plot(dang4_5L), title('IV vs V'), xlim([0 length(Dl)]), ylim([0 180])

end

